# QT4C

QT4C (Quick Test for Client) is a QTA test automation driver for Win32 client application.

## Features
* Powerful UI driver, support Windows native controls, Web controls, Accessibility controls
* Writing maintainable functional tests with QTA QPath technology and QTA UI framework

QT4C should be used with [QTAF](https://github.com/Tencent/QTAF), please check it first.

### Get Started
Check out our [Usage Document](https://qt4c.readthedocs.io/zh_CN/latest/) to get going with QT4C. There is also [sample code](https://github.com/qtacore/QT4CDemoProj) that shows how to run testcase with QT4C.

### Anatomy
If you are interested in anatomy of QT4C, the [Design Document](https://github.com/Tencent/QT4C/blob/master/design/design.md) may be useful to you.

------------------------------
 
QT4C (Quick Test for Client)，基于QTA提供面向Win32应用的UI测试自动化测试框架。

## 特性
* 强大UI驱动引擎支持，Windows Native控件、Web控件、Accessibility控件
* 基于QPath技术和QTA UI框架，降低产品变化的脚本维护投入

QT4C需要和[QTAF](https://github.com/Tencent/QTAF)一起使用，请先参考QTAF的使用

### 入门指南
请查看我们的[使用文档](https://qt4c.readthedocs.io/zh_CN/latest/)以便您快速上手QT4C，同时可以参考我们的[示例代码](https://github.com/qtacore/QT4CDemoProj)。

### 框架原理
如果你对QT4C的实现原理感兴趣，可以参考我们的[设计文档](https://github.com/Tencent/QT4C/blob/master/design/design.md)。

------------------------------

欢迎加入QQ群（432699528）交流使用和反馈
